import applySpec from 'ramda/src/applySpec';

import { getAwardCardData } from './award-card-model';
import { getBrandCardData } from './brand-card-model';
import { getCheckoutCardData } from './checkout-card-model';
import { getHeroCardLevel1CardData } from './hero-card-level1-model';
import { getHeroCardLevel2CardData } from './hero-card-level2-model';
import { getIconTextCardData } from './icon-text-card-model';
import { getLargeCardData } from './large-card-model';
import { getMediumCardData } from './medium-card-model';
import { getPostCardData } from './post-card-model';
import { getSmallFullCardData } from './small-full-card-model';
import { CardTypeName } from './types';
import { getXLargeCardData } from './xlarge-card-model';

const getCardDataModel = (component: any) => {
    const name = component.variant;
    const { values, variant, endIcon, icon } = component;
    const data = {
        [variant]: {
            ...values,
            ...(endIcon && { endIcon }),
            ...(icon && { icon })
        }
    };
    switch (name) {
        case CardTypeName.PostCard:
            return getPostCardData(data);
        case CardTypeName.BrandCard:
            return getBrandCardData(data);
        case CardTypeName.CheckoutCard:
            return getCheckoutCardData(data);
        case CardTypeName.HeroLevel1Card:
            return getHeroCardLevel1CardData(data);
        case CardTypeName.HeroLevel2Card:
            return getHeroCardLevel2CardData(data);
        case CardTypeName.IconTextCard:
            return getIconTextCardData(data);
        case CardTypeName.LargeCard:
            return getLargeCardData(data);
        case CardTypeName.MediumCard:
            return getMediumCardData(data);
        case CardTypeName.XLargeCard:
            return getXLargeCardData(data);
        case CardTypeName.SmallFullCard:
            return getSmallFullCardData(data);
        case CardTypeName.AwardCard:
            return getAwardCardData(data);
        default:
            return {};
    }
};

const getCardData = applySpec({
    card: getCardDataModel
});

export default getCardData;
