import { PropsWithChildren, ReactElement } from 'react';

import { styled } from '@nuskin/foundation-theme';

import { CtaLinkBlockMap } from './CtaLinkMap';
import { CtaLinkProps } from './types/types';

const getBlockUUID = (block: any) => {
    return block['ctaVariant'];
};

const CtaLinkContainer = styled('div')(() => {
    return {
        margin: '0 auto'
    };
});

const NsCTALink = ({ ctaProps, liveTag }: PropsWithChildren<CtaLinkProps>): ReactElement => {
    if (!ctaProps?.text) return <></>;
    const pageBlocks = ctaProps || {};
    const blockType = getBlockUUID(pageBlocks) || 'primary';
    const ctaBody = CtaLinkBlockMap[blockType];
    const blockData: any = ctaBody?.dataParser(pageBlocks)?.['CtaItem'];
    const BlockComponent = ctaBody?.component || null;
    if (!BlockComponent) return <></>;
    return (
        <CtaLinkContainer className="ctaLink-container" data-testid="ctaLink-component" {...liveTag}>
            <BlockComponent {...blockData} role="link" />
        </CtaLinkContainer>
    );
};

export default NsCTALink;
