import { AllColorKeyType } from '@nuskin/foundation-theme';

import { render } from '../../../../test-utils';
import { SplitBannerProps } from '../../types/types';
import SplitBanner from './SplitBanner';
import { imageString1 } from '../../../fixtures/images';

const renderComponent = (props: SplitBannerProps) => render(<SplitBanner heroItem={props} />);

describe('Hero - SplitBanner', () => {
    const positiveTests = [
        {
            given: 'image',
            props: {
                show: true,
                backgroundColor: 'transparent' as AllColorKeyType,
                image: imageString1
            },
            className: 'bynder-image'
        },
        {
            given: 'title',
            props: {
                backgroundColor: 'transparent' as AllColorKeyType,
                image: '',
                show: true,
                header: 'mock title'
            },
            testId: 'title'
        },
        {
            given: 'description',
            props: {
                image: '',
                backgroundColor: 'transparent' as AllColorKeyType,
                description: 'mock description',
                show: true
            },
            testId: 'description'
        }
    ];

    positiveTests.forEach(({ given, props, testId, className }) => {
        describe(`When ${given} is provided`, () => {
            it(`It should render the ${testId}`, () => {
                const { getByTestId, container } = renderComponent(props);
                const el = testId ? getByTestId(testId) : container.querySelector(`.${className}`);
                expect(el).toBeInTheDocument();
            });
        });
    });

    const mockLink = {
        url: 'mock url',
        text: 'mock display name'
    };
    // links
    describe('When call to action is provided', () => {
        const props = {
            backgroundColor: 'transparent' as AllColorKeyType,
            callToAction: mockLink,
            show: true,
            image: ''
        };
        it('It shouid render the call to action', () => {
            const { getByTestId } = renderComponent(props);
            const el = getByTestId('cta');
            expect(el).toBeInTheDocument();
        });

        describe('But has no url', () => {
            const props = {
                backgroundColor: 'transparent' as AllColorKeyType,
                callToAction: {
                    ...mockLink,
                    url: undefined as any
                },
                image: '',
                show: true
            };
            it('It should not render the call to action', () => {
                const { queryByTestId } = renderComponent(props);
                const el = queryByTestId('cta');
                expect(el).not.toBeInTheDocument();
            });
        });

        describe('But has no displayName', () => {
            const props = {
                backgroundColor: 'transparent' as AllColorKeyType,
                callToAction: {
                    ...mockLink,
                    text: undefined as any
                },
                image: '',
                show: true
            };
            it('It should not render the call to action', () => {
                const { queryByTestId } = renderComponent(props);
                const el = queryByTestId('cta');
                expect(el).not.toBeInTheDocument();
            });
        });
    });
});
