import { ColorUtils, styled } from '@nuskin/foundation-theme';
import { AllColorKeyType } from '@nuskin/foundation-theme/src/common/themes/genome-colors';

import { breakpoints } from '../../theme';

const { getGenomeColor } = ColorUtils;
// TODO: move specific sizes to corresponding variant styled components
const TEXT_CONTAINER_SIZE = {
    [breakpoints.md]: {
        height: 'auto',
        width: `${(400 / 768) * 100}%`
    },
    [breakpoints.lg]: {
        height: 'auto',
        width: '48%'
    },
    [breakpoints.xl]: {
        height: 'auto',
        width: '51%'
    }
};

const IMAGE_CONTAINER_SIZE = {
    [breakpoints.md]: {
        // height: '460px',
        height: 'calc(100% - 60px)',
        width: `${(380 / 768) * 100}%`
    },
    [breakpoints.lg]: {
        // height: '460px',
        height: 'calc(100% - 60px)',
        width: `${(560 / 1024) * 100}%`
    },
    [breakpoints.xl]: {
        height: 'calc(100% - 60px)',
        width: `${(750 / 1440) * 100}%`
    }
};
export const ShowcaseTextContainer = styled.div<{
    fontColor?: string;
    backgroundColor: AllColorKeyType;
}>`
    position: relative;
    padding: 32px;
    color: ${({ fontColor = '' }) => fontColor};
    background-color: ${({ backgroundColor, theme }) => getGenomeColor(theme, backgroundColor)};

    .pre-header {
        margin-bottom: 20px;
    }

    .description {
        margin-top: 24px;
    }
    .ctaLink-container {
        margin-top: 40px;
    }

    .cs-button {
        margin: 0;
        padding: 0;
    }

    & > .accent-image-container {
        display: none;
    }

    ${breakpoints.md} {
        padding: 78px 64px;
        position: relative;
        z-index: 2;

        & > .accent-image-container {
            display: block;
        }

        .image-align-left & {
            order: 2;
        }
    }

    ${Object.keys(TEXT_CONTAINER_SIZE).map(
        (media) => `
        ${media} {
            height: ${TEXT_CONTAINER_SIZE[media].height};
            width: ${TEXT_CONTAINER_SIZE[media].width};
        }
    `
    )}
`;

export const ShowcaseImageContainer = styled.div`
    overflow: hidden;
    height: 320px;

    img {
        object-fit: cover;
        width: 100%;
        height: 100%;
    }

    ${breakpoints.md} {
        position: absolute;
        top: 60px;
        height: calc(100% - 60px);
        z-index: 2;

        .image-align-left & {
            left: 0;
            z-index: 1;
        }

        .image-align-right & {
            right: 0;
            z-index: 1;
        }
    }

    ${Object.keys(IMAGE_CONTAINER_SIZE).map(
        (media) => `
        ${media} {
            height: ${IMAGE_CONTAINER_SIZE[media].height};
            width: ${IMAGE_CONTAINER_SIZE[media].width};
        }
    `
    )}
`;

export const ShowcaseContentContainer = styled('div')<{
    backgroundColor: AllColorKeyType;
}>`
    position: relative;
    background-color: ${({ backgroundColor, theme }) => getGenomeColor(theme, backgroundColor)};
    ${breakpoints.md} {
        display: flex;
        flex-direction: row;
        flex-wrap: wrap;
        align-items: start;
        justify-content: start;
        position: relative;

        &.image-align-left {
            justify-content: end;
        }
    }
`;
