import {
    AllColorKeyType,
    styled
} from '@nuskin/foundation-theme';
import { getGenomeColor } from '@nuskin/foundation-theme/src/common/themes/genome-colors/ColorFunctions';
import { NsTypography } from '@nuskin/foundation-ui-components';

import { breakpoints } from '../../../theme';

export const ShowCaseContainer = styled.div<{ alignment: 'left' | 'right' }>`
    display: flex;
    justify-content: center;
    align-items: center;
    overflow: hidden;
    padding: 32px 0px;
    flex-direction: ${({ alignment }) => (alignment === 'left' ? 'column' : 'column-reverse')};
    ${breakpoints.md} {
        flex-direction: ${({ alignment }) => (alignment === 'left' ? 'row' : 'row-reverse')};
        padding: 36px;
    }
`;

export const BulletPoint = styled('div')<{ bulletBackground: AllColorKeyType }>(({
    bulletBackground,
    theme
}) => {
    const minWidth = '36px';
    return {
        display: 'flex',
        minWidth,
        width: minWidth,
        height: minWidth,
        marginBottom: 'auto',
        backgroundColor: getGenomeColor(theme, bulletBackground),
        borderRadius: '50%',
        padding: '8px',
        placeItems: 'center'
    };
});

const getAlignment = (variant: string) => {
    if (variant === 'list') {
        return '36px';
    }
    if (variant === 'accent') {
        return '96px';
    }
    return '120px';
};

export const CardListTitle = styled(NsTypography)`
    font-size: 26px;
    line-height: 32px;
    ${breakpoints.sm} {
        font-size: 22px;
        line-height: 28px;
    }
    ${breakpoints.lg} {
        font-size: 26px;
        line-height: 32px;
    }
`;

export const ShowCaseCardContainer = styled('div')<{
    alignment: 'left' | 'right';
    variant: string;
}>(({ alignment, variant }) => {
    const topStyle = {
        top: alignment === 'left' ? '-36px;' : '36px'
    };
    return {
        position: 'relative',
        ...(variant !== 'accent' ? topStyle : {}),
        '.cta-btn': {
            marginTop: '36px',
            '.MuiButton-link': {
                fontWeight: 'bold',
                textDecoration: 'underline',
                textUnderlineOffset: '4px',
                textDecorationColor: 'currentcolor'
            }
        },
        [breakpoints.md]: {
            [alignment === 'left' ? 'right' : 'left']: getAlignment(variant),
            fontSize: '18px',
            lineHeight: '24px',
            top: '0px',
            '.cta-btn': {
                marginTop: '40px'
            }
        }
    };
});

export const ShowCaseListImageContainer = styled('div')<{ alignment: 'left' | 'right' }>(({
    alignment
}) => {
    return {
        display: 'flex',
        flexDirection: 'column',
        alignItems: 'flex-start',
        flexShrink: '0',
        width: '320px',
        height: '240px',
        position: 'relative',
        img: {
            width: '100%',
            height: '100%',
            objectFit: 'cover'
        },
        [breakpoints.md]: {
            [alignment]: '80px',
            width: '480px',
            height: '484px'
        },
        [breakpoints.lg]: {
            width: '536px',
            height: '528px'
        }
    };
});

export const ShowCaseListCardContainer = styled('div')<{
    alignment: 'left' | 'right';
    backgroundColor: AllColorKeyType;
}>(({ theme, alignment, backgroundColor }) => {
    const padding = alignment === 'left' ? '64px 32px 64px 64px' : '64px 64px 64px 32px';
    return {
        marginInline: 'auto',
        width: '90%',
        height: 'auto',
        backgroundColor: getGenomeColor(theme, backgroundColor),
        flexShrink: 0,
        opacity: 1,
        '.showcase-list-item-text': {
            fontSize: '18px',
            lineHeight: '24px'
        },
        [breakpoints.md]: {
            width: '480px',
            position: 'relative',
            [alignment === 'left' ? 'right' : 'left']: '36px',
            maxWidth: '90%',
            minHeight: '300px',
            ['.showcase-list-item-text']: {
                fontSize: '16px',
                lineHeight: '22px'
            },
            padding,
            alignItems: 'flex-start'
        },
        [breakpoints.lg]: {
            width: '600px',
            minHeight: '400px',
            ['.showcase-list-item-text']: {
                fontSize: '18px',
                lineHeight: '24px'
            }
        }
    };
});
