import { AllColorKeyType } from '@nuskin/foundation-theme';
import { CslpTag, NsTypography } from '@nuskin/foundation-ui-components';
import Check from '@nuskin/foundation-ui-components/src/common/icon/icons/Check';
import { ReactElement } from 'react';

import {
    BulletPoint,
    CardListTitle,
    ShowCaseCardContainer,
    ShowCaseContainer,
    ShowCaseListCardContainer,
    ShowCaseListImageContainer
} from './ShowcaseList.styled';
import { BynderImage } from '../../../bynder-image/BynderImage';
import { useToggleFontColor } from '../../../hooks';
import { CsImageAlignment } from '../../../showcase/types/types';
import { getBasicDATWidthHeight } from '../../../utils/bynder-util';

export interface ShowCaseListProps {
    image: string;
    backgroundColor: AllColorKeyType;
    alignment: CsImageAlignment;
    entries: string[];
    title: string;
    fontColor: boolean;
    iconBgColor: AllColorKeyType;
    iconColor: boolean;
    liveTags?: Record<string, CslpTag>;
}
/** figma link: https://www.figma.com/file/au1aFF1LgN0OyQHdPZDZXb/%5BHIRAYA%5D-FFG-CSR?type=design&node-id=15624-27094&mode=dev */
const ShowCaseList = (props: ShowCaseListProps): ReactElement => {
    const {
        title,
        image,
        entries,
        backgroundColor,
        fontColor,
        iconBgColor,
        iconColor,
        liveTags,
        alignment = 'right'
    } = props;
    const resolvedFontColor = useToggleFontColor(fontColor);
    const resolvedIconColor = useToggleFontColor(iconColor);
    return (
        <ShowCaseContainer alignment={alignment} className="showcase-container">
            <ShowCaseListImageContainer
                data-testid="show-case-list-image"
                alignment={alignment}
                className="showcase-list-image-container"
            >
                <BynderImage
                    imageText={image}
                    suffix={getBasicDATWidthHeight(500, 500, 'scale')}
                    liveTag={liveTags?.image ?? { 'data-cslp': '' }}
                />
            </ShowCaseListImageContainer>
            <ShowCaseCardContainer alignment={alignment} variant="list" className="showcase-card-container">
                <ShowCaseListCardContainer
                    alignment={alignment}
                    backgroundColor={backgroundColor}
                    className="showcase-list-card-container flex flex-col justify-center items-center p-8 gap-2"
                >
                    {title ? (
                        <CardListTitle
                            additionalProps={{
                                ...liveTags?.title,
                                'data-testid': 'showcase-list-title'
                            }}
                            variant="h1"
                            className="card-list-title mb-4"
                            weight="normal"
                            color={fontColor ? 'secondary' : 'primary'}
                        >
                            {title}
                        </CardListTitle>
                    ) : null}
                    <div {...liveTags?.entries}>
                        {entries?.map((item: string, index: number) => {
                            return (
                                <div
                                    className="showcase-list-item flex gap-4 mr-auto my-4 items-center"
                                    key={item + index}
                                    data-testid="show-case-list-item"
                                >
                                    <BulletPoint
                                        className="bullet-point"
                                        {...liveTags?.icon_background_color}
                                        bulletBackground={iconBgColor}
                                    >
                                        <Check
                                            fill={resolvedIconColor}
                                            {...liveTags?.icon_color}
                                            height="20px"
                                            width="20px"
                                        />
                                    </BulletPoint>
                                    <NsTypography
                                        variant="body-xl"
                                        color="primary"
                                        colorOverride={resolvedFontColor}
                                        className="showcase-list-item-text"
                                        noSpacing
                                    >
                                        {item}
                                    </NsTypography>
                                </div>
                            );
                        })}
                    </div>
                </ShowCaseListCardContainer>
            </ShowCaseCardContainer>
        </ShowCaseContainer>
    );
};

export default ShowCaseList;
