import { PropsWithChildren, ReactElement } from 'react';

import { Show } from '@nuskin/foundation-ui-components';

import { StatementBlockMap } from './SatementMap';
import { ItemsProps, StatementParserProps } from './types/types';

const getBlockUUID = (block: ItemsProps) => {
    return Object.keys(block) && Object.keys(block)[0];
};

const getPageBlocks = (props: StatementParserProps) => {
    return props.statement?.[0];
};

const NsStatementComponent = (props: PropsWithChildren<StatementParserProps>): ReactElement => {
    const pageBlocks = getPageBlocks(props);
    if (!pageBlocks) return <></>;

    const blockType = getBlockUUID(pageBlocks);
    const statementBody = StatementBlockMap[blockType];
    const blockData: any = statementBody?.dataParser(pageBlocks);

    const BlockComponent = statementBody?.component;

    return (
        <Show when={!!BlockComponent}>
            <BlockComponent {...blockData} />
        </Show>
    );
};

export default NsStatementComponent;
