type Headers = Record<string, any>;
type RequestCredentials = 'include' | 'omit' | 'same-origin';

type Option = {
    delay?: number;
    cors?: 'cors' | 'no-cors' | 'same-origin';
    headers?: Headers;
    omitContentType?: boolean;
};

export interface ApiRequest {
    endpoint?: string;
    method?: 'GET' | 'PATCH' | 'PUT' | 'POST' | 'DELETE';
    payload?: Record<string, any>;
    options?: Option;
    credentials?: RequestCredentials;
}

const DEFAULT_CORS = 'cors';

const DEFAULT_HEADERS: Headers = {
    Accept: 'application/json',
    'Content-Type': 'application/json',
};

export const fetchApi = async <T>({
    endpoint,
    options,
    method = 'GET',
    payload,
    credentials = 'include',
}: ApiRequest): Promise<T> => {
    const body = payload ? JSON.stringify({ ...payload }) : null;
    const mode = options?.cors ? options.cors : DEFAULT_CORS;

    if (options?.omitContentType) {
        delete DEFAULT_HEADERS['Content-Type'];
    }

    const headers = {
        ...DEFAULT_HEADERS,
        ...(options?.headers || {}),
    };

    if (endpoint) {
        return fetch(endpoint, { method, headers, body, mode, credentials })
            .then((response) => {
                if (response.ok) {
                    return response.json();
                } else {
                    throw new Error(`Error: ${response.status}`);
                }
            })
            .catch((error) => {
                console.error('API Error::', error);
                throw error;
            });
    }
    return Promise.reject('endpoint url not defined');
};
