import { getColorName, parseJsonString } from '../base-util';

describe('A. base-utils.getColorName', () => {
    it('1. should return the color name from the \'brandColor\' object in a valid JSON string', () => {
        const colorExtensionString =
            '{"brandColor": {"colorName": "A10","colorObj":{ "light": "#E5EDF6","dark": "#14324F"}}}';
        const result = getColorName(colorExtensionString);
        expect(result).toBe('A10');
    });
    it('2. should return the default color name if the \'brandColor\' object or the JSON string is not valid', () => {
        const colorExtensionString = '{"brandColor": "red"}';
        const result = getColorName(colorExtensionString);
        expect(result).toBe('transparent');
    });
    it('3. should return the default color name if the \'colorName\' property is not present in the \'brandColor\' object', () => {
        const colorExtensionString = '{"brandColor": {}}';
        const result = getColorName(colorExtensionString);
        expect(result).toBe('transparent');
    });
    it('4. should return the default color name if the input string is null or undefined', () => {
        const colorExtensionString = null;
        const result = getColorName(colorExtensionString as any);
        expect(result).toBe('transparent');
    });
    it('5. should return the default color name if the input string is not a valid JSON string', () => {
        const colorExtensionString = 'invalidJson';
        const result = getColorName(colorExtensionString);
        expect(result).toBe('transparent');
    });
});

describe('B. base-utils.parseJsonString', () => {
    it('1. should successfully parse a valid JSON string', () => {
        const jsonString = '{"name": "John", "age": 30}';
        expect(parseJsonString(jsonString)).toEqual({ name: 'John', age: 30 });
    });
    it('2. should return an empty object when parsing an empty string', () => {
        const jsonString = '';
        expect(parseJsonString(jsonString)).toEqual({});
    });
});
